.. djecrety documentation master file, created on Tue Feb 12 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to djecrety's documentation!
==================================

.. toctree::
    :maxdepth: 2
    :caption: Basics

    introduction
    getting_started
    usage
